@@ -1,5 +1,4 @@
-`pscoast` <-
-function(cmd, file=getOption("gmt.file"))
+pscoast <- function(cmd, file=getOption("gmt.file"))
 {
   if(is.null(file)) stop("Please pass a valid 'file' argument, or run gmt(file=\"myfile\").")
   owd <- setwd(dirname(file)); on.exit(setwd(owd))
@@ -8,4 +7,3 @@ function(cmd, file=getOption("gmt.file"))
 
   invisible(NULL)
 }
-
